.. _tutor_datagen:

DataGen
=======

DataGen extension provides utilities for data generation.

Following generators are supported.

* ASN.1: encoder/decoder with ASN.1 specification
* JSON: sample generator from JSON specification
* XML: sample generator from WSDL/XSD specification

.. toctree::
   :maxdepth: 1
   
   tut1_asn1
   tut2_json
   tut3_xml
   tut4_serializer